@@ -566,24 +566,16 @@ void DbConnectPanel::save_connection_as(const std::string &name) {
   db_mgmt_ConnectionRef conn(_connection->get_connection());
 
   grt::ListRef<db_mgmt_Connection> list(_connection->get_db_mgmt()->storedConns());
-  if (list.get_index(conn) != grt::BaseListRef::npos)
-    throw std::invalid_argument("The connection cannot be saved because it is already stored");
 
   db_mgmt_ConnectionRef dup;
   if ((dup = find_named_object_in_list(list, name, true, "name")).is_valid()) {
     list->remove(dup);
-    // throw std::invalid_argument(strfmt("The connection cannot be saved. There already is a connection named '%s'",
-    // name.c_str()));
   }
 
   list = _connection->get_db_mgmt()->otherStoredConns();
-  if (list.get_index(conn) != grt::BaseListRef::npos)
-    throw std::invalid_argument("The connection cannot be saved because it is already stored");
 
   if ((dup = find_named_object_in_list(list, name, true, "name")).is_valid()) {
     list->remove(dup);
-    // throw std::invalid_argument(strfmt("The connection cannot be saved. There already is a connection named '%s'",
-    // name.c_str()));
   }
 
   conn->name(name);
@@ -624,8 +616,8 @@ bool DbConnectPanel::test_connection() {
         // check that we're connecting to a known and supported version of the server
         std::string version;
         {
-          std::auto_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
-          std::auto_ptr<sql::ResultSet> result(stmt->executeQuery("SELECT version()"));
+          std::unique_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
+          std::unique_ptr<sql::ResultSet> result(stmt->executeQuery("SELECT version()"));
           if (result->next())
             version = result->getString(1);
         }
@@ -647,8 +639,8 @@ bool DbConnectPanel::test_connection() {
 
         // check ssl
         {
-          std::auto_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
-          std::auto_ptr<sql::ResultSet> result(stmt->executeQuery("SHOW SESSION STATUS LIKE 'Ssl_cipher'"));
+          std::unique_ptr<sql::Statement> stmt(_dbc_conn->createStatement());
+          std::unique_ptr<sql::ResultSet> result(stmt->executeQuery("SHOW SESSION STATUS LIKE 'Ssl_cipher'"));
           if (result->next())
             ssl_cipher = result->getString(2);
 
