@@ -30,6 +30,7 @@
 #include "base/log.h"
 #include "base/common.h"
 #include "base/string_utilities.h"
+#include "base/file_utilities.h"
 #include "workbench/wb_version.h"
 
 // Windows includes
@@ -67,7 +68,6 @@
 #include <unistd.h>
 #endif
 
-// MacOS X
 #if defined(__APPLE__) && defined(__MACH__)
 #include <sys/sysctl.h>
 #include <mach/machine.h>
@@ -87,77 +87,6 @@ struct hardware_info {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-static void __sappend(char **str, int *ressize, int *reslen, const char *sbegin, int count) {
-  if (*reslen + count + 1 >= *ressize) {
-    *ressize += count + 100;
-    *str = (char *)g_realloc(*str, *ressize);
-  }
-#ifdef _MSC_VER
-  strncpy_s(*str + *reslen, *reslen, sbegin, count);
-#else
-  strncpy(*str + *reslen, sbegin, count);
-#endif
-
-  *reslen += count;
-  (*str)[*reslen] = 0;
-}
-
-//----------------------------------------------------------------------------------------------------------------------
-
-char *str_g_subst(const char *str, const char *search, const char *replace) {
-  int ressize, reslen;
-  int replsize = (int)strlen(replace);
-  int searchlen = (int)strlen(search);
-  char *res;
-  const char *bptr, *ptr;
-
-  g_return_val_if_fail(str != NULL, g_strdup(str));
-  if (str[0] == '\0') {
-    return g_strdup(str);
-  }
-  g_return_val_if_fail(search != NULL && *search, g_strdup(str));
-  g_return_val_if_fail(replace != NULL, g_strdup(str));
-
-  ressize = (int)strlen(str) + 1;
-  reslen = 0;
-  res = (char *)g_malloc(ressize);
-
-  bptr = str;
-
-  while ((ptr = strstr(bptr, search)) != NULL) {
-    __sappend(&res, &ressize, &reslen, bptr, (int)(ptr - bptr));
-    bptr = ptr + searchlen;
-    __sappend(&res, &ressize, &reslen, replace, replsize);
-  }
-  __sappend(&res, &ressize, &reslen, bptr, (int)strlen(bptr));
-
-  return res;
-}
-
-//----------------------------------------------------------------------------------------------------------------------
-
-/**
- * Replaces the search string with the replace string
- * in the given str
- *
- * @str becomes invalid after calling this
- * function!
- *
- * Return value: Newly allocated result string
- **/
-char *str_g_replace(char *str, const char *search, const char *replace) {
-  char *res;
-
-  if (!replace)
-    replace = "";
-
-  res = str_g_subst(str, search, replace);
-  g_free(str);
-  return res;
-}
-
-//----------------------------------------------------------------------------------------------------------------------
-
 char *auto_line_break(const char *txt, unsigned int width, char sep) {
   char *dst = (char *)g_malloc((width + 2) * 80);
   unsigned int i, o = 0, p = 0, w = 0, l = (unsigned int)strlen(txt);
@@ -371,22 +300,10 @@ std::string get_local_os_name() {
   *dot_position = 0;
   int version = base::atoi<int>(info.release, 0);
   switch (version) {
+    case 19:
+      return std::string("macOS 10.15.x Catalina ") + info.machine;
     case 18:
       return std::string("macOS 10.14.x Mojave ") + info.machine;
-    case 17:
-      return std::string("macOS 10.13.x High Sierra ") + info.machine;
-    case 16:
-      return std::string("macOS 10.12.x Sierra ") + info.machine;
-    case 15:
-      return std::string("OS X 10.11.x El Capitan ") + info.machine;
-    case 14:
-      return std::string("OS X 10.10.x Yosemite ") + info.machine;
-    case 13:
-      return std::string("OS X 10.9.x Mavericks ") + info.machine;
-    case 12:
-      return std::string("OS X 10.8.x Mountain Lion ") + info.machine;
-    case 11:
-      return std::string("OS X 10.7.x Lion ") + info.machine;
   }
   return "unknown";
 }
@@ -497,7 +414,7 @@ static const char *get_cpu_type_name(int cpu_type, int cpu_subtype) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-// MacOS X
+// macOS
 static int _get_hardware_info(hardware_info &info) {
   int mib[2];
   size_t length;
@@ -815,62 +732,6 @@ const char *strfindword(const char *str, const char *word) {
 
 //--------------------------------------------------------------------------------------------------
 
-// TODO: move to file_functions
-/**
- * Copies a file whose name is given by source to target. File names are expected to be encoded
- * as UTF-8.
- *
- * @param source The name + path of the file to copy.
- * @param target The name + path where the new file should be copied to.
- * @return 1 if the operation was successfull, otherwise 0.
- */
-int copy_file(const char *source, const char *target) {
-#ifdef _MSC_VER
-  {
-    const int cch_buf = MAX_PATH;
-    WCHAR src_path[MAX_PATH];
-    WCHAR dest_path[MAX_PATH];
-
-    MultiByteToWideChar(CP_UTF8, 0, source, -1, src_path, cch_buf);
-    MultiByteToWideChar(CP_UTF8, 0, target, -1, dest_path, cch_buf);
-
-    if (!CopyFileW(src_path, dest_path, 0))
-      return 0;
-    return 1;
-  }
-#else
-  // copy contents of original archive to new
-  char buffer[1024 * 4];
-  size_t c;
-  FILE *in, *out;
-  in = base_fopen(source, "r");
-  if (!in)
-    return 0;
-
-  out = base_fopen(target, "w+");
-  if (!out) {
-    fclose(in);
-    return 0;
-  }
-
-  while ((c = fread(buffer, 1, sizeof(buffer), in)) > 0 && c != (size_t)-1) {
-    if (fwrite(buffer, 1, c, out) < c) {
-      int e = errno;
-      fclose(in);
-      fclose(out);
-      errno = e;
-      return 0;
-    }
-  }
-  fclose(in);
-  fclose(out);
-
-  return 1;
-#endif
-}
-
-//----------------------------------------------------------------------------------------------------------------------
-
 // TODO: move to file_functions
 /**
  * Copies all files non-recursively from source to target. Target will be created on the fly.
@@ -889,7 +750,7 @@ int copy_folder(const char *source_folder, const char *target_folder) {
     while ((entry = g_dir_read_name(dir)) != NULL) {
       char *source = g_build_filename(source_folder, entry, NULL);
       char *target = g_build_filename(target_folder, entry, NULL);
-      if (!copy_file(source, target)) {
+      if (!base::copyFile(source, target)) {
         logWarning("Could not copy file %s to %s: %s\n", source, target, g_strerror(errno));
         g_free(source);
         g_free(target);
