@@ -18,20 +18,25 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "driver_manager.h"
 
+#include "wb_tunnel.h"
+
 #include "mysql_driver.h"
 #include "cppconn/driver.h"
 #include "cppconn/statement.h"
 #include "cppconn/exception.h"
 #include "cppconn/metadata.h"
 #include "base/string_utilities.h"
+#include "grt.h"
 
 #include <gmodule.h>
 
+using namespace wb;
+
 namespace sql {
 
   typedef std::map<std::string, std::string> Param_types;
@@ -154,14 +159,14 @@ namespace sql {
     _driver_path = path;
   }
 
-  std::shared_ptr<TunnelConnection> DriverManager::getTunnel(const db_mgmt_ConnectionRef &connectionProperties) {
+  std::shared_ptr<SSHTunnel> DriverManager::getTunnel(const db_mgmt_ConnectionRef &connectionProperties) {
     db_mgmt_DriverRef drv = connectionProperties->driver();
     if (!drv.is_valid())
       throw SQLException("Invalid connection settings: undefined connection driver");
 
     if (_createTunnel)
       return _createTunnel(connectionProperties);
-    return std::shared_ptr<TunnelConnection>();
+    return std::shared_ptr<SSHTunnel>();
   }
 
 //--------------------------------------------------------------------------------------------------
@@ -174,7 +179,7 @@ namespace sql {
     if (!drv.is_valid())
       throw SQLException("Invalid connection settings: undefined connection driver");
 
-    std::shared_ptr<TunnelConnection> tunnel;
+    std::shared_ptr<SSHTunnel> tunnel;
     if (_createTunnel) {
       tunnel = _createTunnel(connectionProperties);
 
@@ -212,7 +217,7 @@ namespace sql {
   //--------------------------------------------------------------------------------------------------
 
   ConnectionWrapper DriverManager::getConnection(const db_mgmt_ConnectionRef &connectionProperties,
-                                                 std::shared_ptr<TunnelConnection> tunnel, Authentication::Ref password,
+                                                 std::shared_ptr<SSHTunnel> tunnel, Authentication::Ref password,
                                                  ConnectionInitSlot connection_init_slot) {
     grt::DictRef parameter_values = connectionProperties->parameterValues();
     if (parameter_values.get_string("userName").empty())
@@ -313,7 +318,7 @@ namespace sql {
       attribs["program_name"] = "MySQLWorkbench";
       properties["OPT_CONNECT_ATTR_ADD"] = attribs;
     }
-    
+
     // If SSL is enabled but there's no certificate or anything, create the sslKey option to force enabling SSL without
     // a key
     // (equivalent to starting cmdline client with mysql --ssl-key=)
@@ -369,7 +374,7 @@ namespace sql {
 
     if (tunnel) {
       // Make the driver connect to the local tunnel port.
-      properties["port"] = tunnel->get_port();
+      properties["port"] = tunnel->getConfig().localport;
       properties["hostName"] = sql::SQLString("127.0.0.1");
     } else
       properties["hostName"] = "[" + parameter_values.get_string("hostName") +
@@ -470,7 +475,7 @@ namespace sql {
       } else {
         stmt->executeUpdate("SET NAMES 'utf8'");
       }
-      
+
       std::string def_schema = parameter_values.get_string("schema", "");
       if (!def_schema.empty())
         conn->setSchema(def_schema);
