@@ -406,6 +406,9 @@ void CodeEditor::updateColors() {
   // Other settings.
   color = Color::getSystemColor(base::SelectedTextBackgroundColor);
   _code_editor_impl->send_editor(this, SCI_SETSELBACK, 1, color.toBGR());
+#ifndef __APPLE__
+  _code_editor_impl->send_editor(this, SCI_SETSELALPHA, 128, 0);
+#endif
 
   if (darkMode) {
     _code_editor_impl->send_editor(this, SCI_SETCARETLINEBACK, 0xFFFFFF, 0);
@@ -801,7 +804,7 @@ void CodeEditor::handleMarkerDeletion(size_t position, size_t length) {
 /**
  * Called after an edit action took place. We have to record markers that got moved by that action.
  */
-void CodeEditor::handleMarkerMove(size_t position, int linesAdded) {
+void CodeEditor::handleMarkerMove(Sci_Position position, Sci_Position linesAdded) {
   if (linesAdded == 0)
     return;
 
@@ -818,7 +821,7 @@ void CodeEditor::handleMarkerMove(size_t position, int linesAdded) {
   }
 
   // Ignore the first line if it has been edited after the line start.
-  if (position > static_cast<size_t>(_code_editor_impl->send_editor(this, SCI_POSITIONFROMLINE, currentLine, 0)))
+  if (position > static_cast<Sci_Position>(_code_editor_impl->send_editor(this, SCI_POSITIONFROMLINE, currentLine, 0)))
     ++currentLine;
 
   currentLine = _code_editor_impl->send_editor(this, SCI_MARKERNEXT, currentLine, LineMarkupAll);
@@ -881,45 +884,42 @@ bool CodeEditor::ensureImage(std::string const& name) {
   if (registeredImages.find(name) != registeredImages.end())
     return true;
 
-  std::string path = App::get()->get_resource_path(name);
-  if (base::file_exists(path) && base::hasSuffix(path, ".png")) {
-    cairo_surface_t* image = Utilities::load_icon(path);
-    if (image == NULL)
-      return false;
+  cairo_surface_t* image = Utilities::load_icon(name);
+  if (image == nullptr)
+    return false;
 
-    if (cairo_surface_status(image) != CAIRO_STATUS_SUCCESS) {
-      cairo_surface_destroy(image);
-      return false;
-    }
-
-    int width = cairo_image_surface_get_width(image);
-    int height = cairo_image_surface_get_height(image);
-
-    unsigned char* data = cairo_image_surface_get_data(image);
-
-    // We not only need to keep the data around for the lifetime of the editor we also have
-    // to swap blue and red.
-    unsigned char *target = reinterpret_cast<unsigned char *>(malloc(4 * width * height));
-    if (target != nullptr) {
-      ImageRecord entry = {
-        Utilities::is_hidpi_icon(image),
-        cairo_image_surface_get_width(image),
-        cairo_image_surface_get_height(image),
-        target
-      };
-      registeredImages[name] = entry;
-      int j = 0;
-      while (j < 4 * width * height) {
-        target[j] = data[j + 2];
-        target[j + 1] = data[j + 1];
-        target[j + 2] = data[j];
-        target[j + 3] = data[j + 3];
-        j += 4;
-      }
-    }
+  if (cairo_surface_status(image) != CAIRO_STATUS_SUCCESS) {
     cairo_surface_destroy(image);
+    return false;
   }
 
+  int width = cairo_image_surface_get_width(image);
+  int height = cairo_image_surface_get_height(image);
+
+  unsigned char* data = cairo_image_surface_get_data(image);
+
+  // We not only need to keep the data around for the lifetime of the editor we also have
+  // to swap blue and red.
+  unsigned char *target = reinterpret_cast<unsigned char *>(malloc(4 * width * height));
+  if (target != nullptr) {
+    ImageRecord entry = {
+      Utilities::is_hidpi_icon(image),
+      cairo_image_surface_get_width(image),
+      cairo_image_surface_get_height(image),
+      target
+    };
+    registeredImages[name] = entry;
+    int j = 0;
+    while (j < 4 * width * height) {
+      target[j] = data[j + 2];
+      target[j + 1] = data[j + 1];
+      target[j + 2] = data[j];
+      target[j + 3] = data[j + 3];
+      j += 4;
+    }
+  }
+  cairo_surface_destroy(image);
+
   return true;
 }
 
@@ -936,23 +936,23 @@ void CodeEditor::loadConfiguration(SyntaxHighlighterLanguage language) {
         version = MySQLVersion::MySQL56;
         break;
       case LanguageMySQL57:
-        version = MySQLVersion::MySQL56;
+        version = MySQLVersion::MySQL57;
         break;
       default:
         version = MySQLVersion::MySQL80;
         break;
     }
 
-    auto &names = MySQLSymbolInfo::systemFunctionsForVersion(version);
+    auto &functions = MySQLSymbolInfo::systemFunctionsForVersion(version);
     std::string list;
-    for (auto const& name : names)
+    for (auto const& name : functions)
       list += base::tolower(name) + " "; // Keyword matching in Scintilla uses lower case compare.
 
     _code_editor_impl->send_editor(this, SCI_SETKEYWORDS, 3, (sptr_t)list.c_str());
 
-    names = MySQLSymbolInfo::keywordsForVersion(version);
+    auto &keywords = MySQLSymbolInfo::keywordsForVersion(version);
     list = "";
-    for (auto const& name : names)
+    for (auto const& name : keywords)
       list += base::tolower(name) + " ";
 
     _code_editor_impl->send_editor(this, SCI_SETKEYWORDS, 1, (sptr_t)list.c_str());
